#ifndef __PROBENTRY_DLG_H
#define __PROBENTRY_DLG_H
/*-------------------------------------------------------------------------
 * Copyright (c) 1999-2000 Kenneth W. Sodemann (stufflehead@bigfoot.com)
 *-------------------------------------------------------------------------
 * probentry_dlg
 *
 * Synopsis:
 *   Dialog for entry of problem reports.
 *
 * $Id: probentry_dlg.h,v 1.6 2002/11/22 20:53:06 stuffle Exp $
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to
 * Free Software Foundation, Inc.
 * 59 Temple Place, Suite 330
 * Boston, MA  02111-1307  USA
 *
 *-------------------------------------------------------------------------
 */
#include <gtk/gtk.h>
#include <libpq-fe.h>

/*-------------------------------------------------------------------------
 * Function:  create_problem_entry_dlg
 *
 * Synopsis:
 *   Create the dialog used to initially enter a problem report
 *   into the system.
 *
 *   Use this function to create non-Modal dialogs.  For modal 
 *   dialogs, use the execute_xxx function.
 *
 * Inputs:
 *   parent : pointer to the widget set that created this one, which
 *            should always be the main application window.
 *   conn   : pointer to the database connection.
 *
 * Outputs:
 *   None.
 * 
 * Return Value:
 *   Pointer to the entry dialog.
 *
 *-------------------------------------------------------------------------
 */
GtkWidget* create_problem_entry_dlg (GtkWidget  *parent,
                                     PGconn     *conn);

/*-------------------------------------------------------------------------
 * Function:  problem_entry_dlg_dirty
 *
 * Synopsis:
 *   Determine if the problem entry dialog has any unsaved data.
 *
 * Inputs:
 *   dlg : pointer to the dialog to check.
 *
 * Outputs:
 *   None.
 * 
 * Return Value:
 *   TRUE  : The dialog has unsaved data.
 *   FALSE : The dialog does not have unsaved data.
 *
 *-------------------------------------------------------------------------
 */
gboolean problem_entry_dlg_dirty (GtkWidget *parent);

#endif
